@@ -1,5 +1,5 @@
+// SPDX-License-Identifier: BSD-3-Clause
 //go:build race
-// +build race
 
 package process
 
@@ -8,7 +8,7 @@ import (
 	"testing"
 )
 
-func Test_Process_Ppid_Race(t *testing.T) {
+func TestPpid_Race(t *testing.T) {
 	wg := sync.WaitGroup{}
 	testCount := 10
 	p := testGetProcess()
